@@ -966,13 +966,16 @@ encode_tmplheader(char **mail)
  *   struct rcptinfo  reference data
  *   char *           recipient address
  *   char **          replaced date
+ *   int              if mode is NOTICEPASS_FROM, in mailbody repalace <@@RCPTLIST@@> by *rcptinfo
+ *                    if mode is NOTICEPASS_TO, in mailbody repalace <@@RCPTLIST@@> by *sender
  *
  * Return:
  *   ERROR		-1   error
  *   SUCCESS		0   success
  */
 int
-tmpl_tag_replace(char *tmp, struct mailzip mz, struct rcptinfo *other, char *sender, char **retp)
+tmpl_tag_replace(char *tmp, struct mailzip mz, struct rcptinfo *other, char *sender, char **retp, 
+                int mode)
 {
 
     int i;
@@ -986,6 +989,8 @@ tmpl_tag_replace(char *tmp, struct mailzip mz, struct rcptinfo *other, char *sen
     int name_len = 0, ret_len = 0, total_len = 0;
     int tagnum = 0;
 
+    struct rcptinfo *p;
+
     /* Repairing for encoded Subject by MIME encode(2014/05/14(wed)) */
     char *tmp_dec = NULL;
 
@@ -1024,9 +1029,11 @@ tmpl_tag_replace(char *tmp, struct mailzip mz, struct rcptinfo *other, char *sen
     tmpl_tag[TOADDR].st_str = sender;
 
     // rcptaddr total length
-    for (i = 0; (other->rcptlist + i)->rcpt_addr != NULL; i++) {
-        rcptaddr_len = (other->rcptlist + i)->rcpt_addr_len;
-        ret += rcptaddr_len + 1;
+    for (p = other; p != NULL; p = p->Next) {
+        for (i = 0; (p->rcptlist + i)->rcpt_addr != NULL; i++) {
+            rcptaddr_len = (p->rcptlist + i)->rcpt_addr_len;
+            ret += rcptaddr_len + 1;
+        }
     }
 
     // allocate memory
@@ -1043,22 +1050,29 @@ tmpl_tag_replace(char *tmp, struct mailzip mz, struct rcptinfo *other, char *sen
     // reset memory
     *tmpp = '\0';
 
-     // write memory
-    for (i = 0; (other->rcptlist + i)->rcpt_addr != NULL; i++) {
-        rcptaddr = (other->rcptlist + i)->rcpt_addr;
-        rcptaddr_len = (other->rcptlist + i)->rcpt_addr_len;
+    for (p = other; p != NULL; p = p->Next) {
+        // write memory
+        for (i = 0; (p->rcptlist + i)->rcpt_addr != NULL; i++) {
+            rcptaddr = (p->rcptlist + i)->rcpt_addr;
+            rcptaddr_len = (p->rcptlist + i)->rcpt_addr_len;
 
-        strcat(tmpp, rcptaddr);
-        *(tmpp + total + rcptaddr_len) = '\n';
-        *(tmpp + total + rcptaddr_len + 1) = '\0';
-        total = total + rcptaddr_len + 1;
+            strcat(tmpp, rcptaddr);
+            *(tmpp + total + rcptaddr_len) = '\n';
+            *(tmpp + total + rcptaddr_len + 1) = '\0';
+            total = total + rcptaddr_len + 1;
+        }
     }
 
     // last '\n' change into '\0'
     *(tmpp + total - 1) = '\0';
 
-    // store all rcptaddr 
-    tmpl_tag[RCPTLIST].st_str = tmpp;
+    if (mode == NOTICEPASS_FROM) {
+        // store all rcptaddr 
+        tmpl_tag[RCPTLIST].st_str = tmpp;
+    } else {
+        // store all rcptaddr 
+        tmpl_tag[RCPTLIST].st_str = sender;
+    }
 
     //file_name
     if (mz.namelist != NULL) {
@@ -1191,6 +1205,8 @@ tmpl_tag_replace(char *tmp, struct mailzip mz, struct rcptinfo *other, char *sen
  *   char *           recipient address
  *   char **          replaced date
  *   char *           convert-error template file path
+ *   int              if mode is NOTICEPASS_FROM, in mailbody repalace <@@RCPTLIST@@> by *rcptinfo
+ *                    if mode is NOTICEPASS_TO, in mailbody repalace <@@RCPTLIST@@> by *sender
  *
  * Return:
  *   ERROR		-1   error
@@ -1198,7 +1214,8 @@ tmpl_tag_replace(char *tmp, struct mailzip mz, struct rcptinfo *other, char *sen
  */
 int
 tmpl_tag_replace_noconv(struct mailzip mz, struct rcptinfo *other, 
-                        char *sender, char **retp, char *filepath)
+                        char *sender, char **retp, char *filepath,
+                        int mode)
 {
     int i;
     char *rcptaddr, *tmpp = NULL, *tmptagp = NULL;
@@ -1209,6 +1226,8 @@ tmpl_tag_replace_noconv(struct mailzip mz, struct rcptinfo *other,
     int tagnum = 0;
     char *template = NULL;
 
+    struct rcptinfo *p;
+
     struct strtag tmpl_tag[] = {
         {"SUBJECT", 7, NULL},
         {"DATE", 4, NULL},
@@ -1231,10 +1250,12 @@ tmpl_tag_replace_noconv(struct mailzip mz, struct rcptinfo *other,
     // set toaddr(sender address)
     tmpl_tag[TOADDR].st_str = sender;
 
-    // rcptaddr total length
-    for (i = 0; (other->rcptlist + i)->rcpt_addr != NULL; i++) {
-        rcptaddr_len = (other->rcptlist + i)->rcpt_addr_len;
-        ret += rcptaddr_len + 1;
+    for (p = other; p != NULL; p = p->Next) {
+        // rcptaddr total length
+        for (i = 0; (other->rcptlist + i)->rcpt_addr != NULL; i++) {
+            rcptaddr_len = (other->rcptlist + i)->rcpt_addr_len;
+            ret += rcptaddr_len + 1;
+        }
     }
 
     // allocate memory
@@ -1247,22 +1268,29 @@ tmpl_tag_replace_noconv(struct mailzip mz, struct rcptinfo *other,
     // reset memory
     *tmpp = '\0';
 
-    // write memory
-    for (i = 0; (other->rcptlist + i)->rcpt_addr != NULL; i++) {
-        rcptaddr = (other->rcptlist + i)->rcpt_addr;
-        rcptaddr_len = (other->rcptlist + i)->rcpt_addr_len;
+    for (p = other; p != NULL; p = p->Next) {
+        // write memory
+        for (i = 0; (p->rcptlist + i)->rcpt_addr != NULL; i++) {
+            rcptaddr = (p->rcptlist + i)->rcpt_addr;
+            rcptaddr_len = (p->rcptlist + i)->rcpt_addr_len;
 
-        strcat(tmpp, rcptaddr);
-        *(tmpp + total + rcptaddr_len) = '\n';
-        *(tmpp + total + rcptaddr_len + 1) = '\0';
-        total = total + rcptaddr_len + 1;
+            strcat(tmpp, rcptaddr);
+            *(tmpp + total + rcptaddr_len) = '\n';
+            *(tmpp + total + rcptaddr_len + 1) = '\0';
+            total = total + rcptaddr_len + 1;
+        }
     }
 
     // last '\n' change into '\0'
     *(tmpp + total - 1) = '\0';
 
-    // store all rcptaddr 
-    tmpl_tag[RCPTLIST].st_str = tmpp;
+    if (mode == NOTICEPASS_FROM) {
+        // store all rcptaddr 
+        tmpl_tag[RCPTLIST].st_str = tmpp;
+    } else {
+        // store all rcptaddr 
+        tmpl_tag[RCPTLIST].st_str = sender;
+    }
 
     //file_name
     if (mz.namelist != NULL) {
