@@ -343,8 +343,8 @@ zip_convert_mail(SMFICTX *ctx, struct mailinfo *minfo, struct config *cfg,
 
 
 	        chk_replace = tmpl_tag_replace(temp, mz, p, from,
-                                               &confirmation_message);
-            switch(chk_replace) {
+                                               &confirmation_message, NOTICEPASS_FROM);
+                switch(chk_replace) {
                 case ERROR:
                     p->passwd = org_p;	/* restore original password */
                     tmpl_release(temp);
@@ -354,7 +354,7 @@ zip_convert_mail(SMFICTX *ctx, struct mailinfo *minfo, struct config *cfg,
                     // replace not converted string
                     chk_replace_noconv = tmpl_tag_replace_noconv(mz, p, from,
                                                                  &confirmation_message,
-                                                                 cfg->cf_errmsgtemplatepath);
+                                                                 cfg->cf_errmsgtemplatepath, NOTICEPASS_FROM);
 
                     if (chk_replace_noconv == ERROR) {
                         tmpl_release(temp);
@@ -521,7 +521,8 @@ zip_convert_mail(SMFICTX *ctx, struct mailinfo *minfo, struct config *cfg,
         /* パスワード通知メールの送信 */
 	temp = tmpl_init();
 
-        chk_replace = tmpl_tag_replace(temp, mz, &tmp_rcptinfo, from, &notify_message);
+        chk_replace = tmpl_tag_replace(temp, mz, &tmp_rcptinfo, from, &notify_message, NOTICEPASS_FROM);
+
         switch(chk_replace) {
             case ERROR:
                 tmpl_release(temp);
@@ -531,7 +532,8 @@ zip_convert_mail(SMFICTX *ctx, struct mailinfo *minfo, struct config *cfg,
             case CONVERT_ERROR:
                 // replace before convert string
                 chk_replace_noconv = tmpl_tag_replace_noconv(mz, &tmp_rcptinfo, from,
-                                                             &notify_message, cfg->cf_errmsgtemplatepath);
+                                                             &notify_message, cfg->cf_errmsgtemplatepath,
+                                                             NOTICEPASS_FROM);
 
                 if (chk_replace_noconv == ERROR) {
                     tmpl_release(temp);
@@ -540,6 +542,7 @@ zip_convert_mail(SMFICTX *ctx, struct mailinfo *minfo, struct config *cfg,
                     return ZIP_CONVERT_FAILED;
                 }
         }
+
 	tmpl_release(temp);
 
         // set header field "references"
@@ -596,10 +599,24 @@ zip_convert_mail(SMFICTX *ctx, struct mailinfo *minfo, struct config *cfg,
                 if ((cfg->cf_passwordnotice == 1) || (cfg->cf_passwordnotice == 2)) {
                     /* make notify message */
                     temp = tmpl_init();
-                    if (tmpl_tag_replace(temp, mz, rdmpasslist, rcptaddr, &notify_message_to) != 0){
+                    chk_replace = tmpl_tag_replace(temp, mz, rdmpasslist, rcptaddr, &notify_message_to, NOTICEPASS_TO);
+
+                    switch(chk_replace) {
+                    case ERROR:
                         tmpl_release(temp);
                         mailzip_clean(mz);
                         return ZIP_CONVERT_FAILED;
+                    case CONVERT_ERROR:
+                        // replace before convert string
+                        chk_replace_noconv = tmpl_tag_replace_noconv(mz, rdmpasslist, rcptaddr,
+                                                                     &notify_message_to, cfg->cf_errmsgtemplatepath,
+                                                                     NOTICEPASS_TO);
+
+                        if (chk_replace_noconv == ERROR) {
+                            tmpl_release(temp);
+                            mailzip_clean(mz);
+                            return ZIP_CONVERT_FAILED;
+                        }
                     }
                     tmpl_release(temp);
 
