@@ -81,6 +81,12 @@ struct mailzip {
     struct name_list *namelist;
     char *encfilepath;
     char *attachfilename;
+#ifdef __CUSTOMIZE2018
+    int  md_depth;
+    int  md_pos;
+    struct addmsg_tmpl *am_tmpl;
+    struct mlfiPriv *am_priv;
+#endif	// __CUSTOMIZE2018
 };
 
 struct rcptinfo {
@@ -119,6 +125,14 @@ void free_rcptinfo(struct rcptinfo *);
 int get_msgid(char **, char *);
 int set_references(char *, char **);
 int replace_extension(char *, char *, char *);
+#ifdef __CUSTOMIZE2018
+void zipconv_log(char *, char *, struct rcptaddr *, struct name_list *, char *);
+char * get_body_head(char *);
+int replace_mime_part(GMimeObject *, GMimeObject *, int, struct mailzip *, GMimeContentType *);
+int is_noenc_qp(char);
+char * encode_qp(char *);
+char * add_message(char *, struct mailzip *, char *, GMimeContentEncoding, GMimeContentType *ctype);
+#endif	// __CUSTOMIZE2018
 
 /* Return Values */
 #define PM_SUCCESS		0
